decorate_warnings

Function decorate_warnings 

pub fn decorate_warnings(
    warning_diags: Diagnostics,
    files: Option<&MappedFiles>,
)
There may be additional information that needs to be displayed after diagnostics are reported (optionally report diagnostics themselves if files argument is provided).