pub struct BuildConfig {
pub config: BuildConfig,
pub run_bytecode_verifier: bool,
pub print_diags_to_stderr: bool,
pub environment: Environment,
}Expand description
Wrapper around the core Move BuildConfig with some Sui-specific info
Fields
config: BuildConfigrun_bytecode_verifier: boolIf true, run the Move bytecode verifier on the bytecode from a successful build
print_diags_to_stderr: boolIf true, print build diagnostics to stderr–no printing if false
environment: EnvironmentThe environment that compilation is with respect to (e.g., required to resolve published dependency IDs).
Implementations
Sourceimpl BuildConfig
impl BuildConfig
pub fn new_for_testing() -> Self
pub fn new_for_testing_replace_addresses<I, S>( dep_original_addresses: I, ) -> Self
pub async fn build_async(self, path: &Path) -> Result<CompiledPackage>
pub async fn build_async_from_root_pkg( self, root_pkg: &mut RootPackage<SuiFlavor>, ) -> Result<CompiledPackage>
Sourcepub fn build(self, path: &Path) -> Result<CompiledPackage>
pub fn build(self, path: &Path) -> Result<CompiledPackage>
Given a path and a build_config, build the package in that path, including its dependencies.
If we are building the Sui framework, we skip the check that the addresses should be 0