pub struct CompiledPackage {
pub package: CompiledPackage,
pub published_at: Option<ObjectID>,
pub dependency_ids: PackageDependencies,
}Expand description
Wrapper around the core Move CompiledPackage with some Sui-specific traits and info
Fields
package: CompiledPackagepublished_at: Option<ObjectID>Address the package is recorded as being published at.
dependency_ids: PackageDependenciesThe dependency IDs of this package
Implementations
Sourceimpl CompiledPackage
impl CompiledPackage
Sourcepub fn get_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_modules(&self) -> impl Iterator<Item = &CompiledModule>
Return all of the bytecode modules in this package (not including direct or transitive deps)
Note: these are not topologically sorted by dependency–use get_dependency_sorted_modules to produce a list of modules suitable
for publishing or static analysis
Sourcepub fn into_modules(self) -> Vec<CompiledModule>
pub fn into_modules(self) -> Vec<CompiledModule>
Return all of the bytecode modules in this package (not including direct or transitive deps)
Note: these are not topologically sorted by dependency–use get_dependency_sorted_modules to produce a list of modules suitable
for publishing or static analysis
Sourcepub fn get_dependent_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_dependent_modules(&self) -> impl Iterator<Item = &CompiledModule>
Return all of the bytecode modules that this package depends on (both directly and transitively) Note: these are not topologically sorted by dependency.
Sourcepub fn get_modules_and_deps(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_modules_and_deps(&self) -> impl Iterator<Item = &CompiledModule>
Return all of the bytecode modules in this package and the modules of its direct and transitive dependencies. Note: these are not topologically sorted by dependency.
Sourcepub fn get_dependency_sorted_modules(
&self,
with_unpublished_deps: bool,
) -> Vec<CompiledModule>
pub fn get_dependency_sorted_modules( &self, with_unpublished_deps: bool, ) -> Vec<CompiledModule>
Return the bytecode modules in this package, topologically sorted in dependency order.
Optionally include dependencies that have not been published (are at address 0x0), if
with_unpublished_deps is true. This is the function to call if you would like to publish
or statically analyze the modules.
Sourcepub fn get_dependency_storage_package_ids(&self) -> Vec<ObjectID>
pub fn get_dependency_storage_package_ids(&self) -> Vec<ObjectID>
Return the set of Object IDs corresponding to this package’s transitive dependencies’ storage package IDs (where to load those packages on-chain).
Sourcepub fn get_package_digest(&self, with_unpublished_deps: bool) -> [u8; 32]
pub fn get_package_digest(&self, with_unpublished_deps: bool) -> [u8; 32]
Return a digest of the bytecode modules in this package.
Sourcepub fn get_package_bytes(&self, with_unpublished_deps: bool) -> Vec<Vec<u8>>
pub fn get_package_bytes(&self, with_unpublished_deps: bool) -> Vec<Vec<u8>>
Return a serialized representation of the bytecode modules in this package, topologically sorted in dependency order
Sourcepub fn get_package_base64(&self, with_unpublished_deps: bool) -> Vec<Base64>
pub fn get_package_base64(&self, with_unpublished_deps: bool) -> Vec<Base64>
Return the base64-encoded representation of the bytecode modules in this package, topologically sorted in dependency order
Sourcepub fn get_deepbook_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_deepbook_modules(&self) -> impl Iterator<Item = &CompiledModule>
Get bytecode modules from DeepBook that are used by this package
Sourcepub fn get_bridge_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_bridge_modules(&self) -> impl Iterator<Item = &CompiledModule>
Get bytecode modules from DeepBook that are used by this package
Sourcepub fn get_sui_system_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_sui_system_modules(&self) -> impl Iterator<Item = &CompiledModule>
Get bytecode modules from the Sui System that are used by this package
Sourcepub fn get_sui_framework_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_sui_framework_modules(&self) -> impl Iterator<Item = &CompiledModule>
Get bytecode modules from the Sui Framework that are used by this package
Sourcepub fn get_stdlib_modules(&self) -> impl Iterator<Item = &CompiledModule>
pub fn get_stdlib_modules(&self) -> impl Iterator<Item = &CompiledModule>
Get bytecode modules from the Move stdlib that are used by this package
Sourcepub fn generate_struct_layouts(&self) -> Registry
pub fn generate_struct_layouts(&self) -> Registry
Generate layout schemas for all types declared by this package, as well as
all struct types passed into entry functions declared by modules in this package
(either directly or by reference).
These layout schemas can be consumed by clients (e.g., the TypeScript SDK) to enable
BCS serialization/deserialization of the package’s objects, tx arguments, and events.
Sourcepub fn is_system_package(&self) -> bool
pub fn is_system_package(&self) -> bool
Checks whether this package corresponds to a built-in framework
Sourcepub fn published_root_module(&self) -> Option<&CompiledModule>
pub fn published_root_module(&self) -> Option<&CompiledModule>
Checks for root modules with non-zero package addresses. Returns an arbitrary one, if one
can be found, otherwise returns None.
pub fn verify_unpublished_dependencies( &self, unpublished_deps: &BTreeSet<Symbol>, ) -> SuiResult<()>
pub fn get_published_dependencies_ids(&self) -> Vec<ObjectID>